@@ -12,8 +12,7 @@ sub journalist {
     my @patterns = (
         qr{\b記者\s*([\p{Letter}、]+?)\s*／\s*(?:\p{Letter}+?)報導\b},
         qr{\b文／([\p{Letter}、]+)\b},
-        qr{\b三立準氣象／(\p{Letter}+?)報導\n},
-        qr{\b(?:娛樂|財經|政治|鄉民|社會|體育|生活|國際)中心／(\p{Letter}+?)報導\n},
+        qr{\b (?:三立準氣象 | \p{Letter}{2} 中心) ／ (\p{Letter}+?) 報導\b}x,
     );
 
     my $name;
@@ -23,12 +22,7 @@ sub journalist {
         last if defined $name;
     }
 
-    return '' unless $name;
-
-    my %exclude = map { $_ => 1 } qw(綜合 台北);
-    return '' if $exclude{$name};
-
-    return normalize_whitespace($name);
+    return $name && normalize_whitespace($name);
 }
 
 1;
